Learn R Programming

httk (version 1.4)

calc_hepatic_clearance: Calculate the hepatic clearance.

Description

This function calculates the hepatic clearance for a well-stirred model or other type if specified.

Usage

calc_hepatic_clearance(chem.name=NULL,chem.cas=NULL,parameters=NULL,species='Human', hepatic.model='well-stirred',suppress.messages=F)

Arguments

chem.name
Either the chemical name, CAS number, or the parameters must be specified.
chem.cas
Either the chemical name, CAS number, or the parameters must be specified.
species
Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or default "Human").

parameters
Chemical parameters from parameterize_steadystate function, overrides chem.name and chem.cas.
hepatic.model
Model used in calculating hepatic clearance, unscaled, parallel tube, dispersion, or default well-stirred.
suppress.messages
Whether or not to suppress the output message.

Value

Hepatic Clearance
Units of L/h/kg BW.

Details

When species is specified as rabbit, dog, or mouse, the function uses the appropriate physiological data(volumes and flows) but substitues human fraction unbound, partition coefficients, and intrinsic hepatic clearance.

Examples

Run this code
calc_hepatic_clearance(chem.name="Ibuprofen")

Run the code above in your browser using DataLab