Learn R Programming

httk (version 1.3)

calc_mc_oral_equiv: Calculate Monte Carlo Oral Equivalent Dose

Description

This functions converts a chemical plasma concetration to an oral equivalent dose using a concentration obtained from calc_mc_css.

Usage

calc_mc_oral_equiv(conc,chem.name=NULL,chem.cas=NULL,which.quantile=0.95,
                   species="Human",input.units='uM',output.units='mg',
                   suppress.messages=F,return.samples=F,...)

Arguments

conc
Bioactive in vitro concentration in units of uM.
chem.name
Either the chemical name or the CAS number must be specified.
chem.cas
Either the CAS number or the chemical name must be specified.
suppress.messages
Suppress text messages.
input.units
Units of given concentration, default of uM but can also be mg/L.
output.units
Units of dose, default of 'mg' for mg/kg BW/ day or 'mol' for mol/ kg BW/ day.
which.quantile
Which quantile from Monte Carlo simulation is requested. Can be a vector.
species
Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or default "Human").
return.samples
Whether or not to return the vector containing the samples from the simulation instead of the selected quantile.
...
Additional parameters passed to calc_mc_css.

Value

  • Equivalent dose in specified units, default of mg/kg BW/day.

Details

When species is specified as rabbit, dog, or mouse, the function uses the appropriate physiological data(volumes and flows) but substitues human fraction unbound, partition coefficients, and intrinsic hepatic clearance.

Examples

Run this code
calc_mc_oral_equiv(0.1,chem.cas="34256-82-1")

calc_mc_oral_equiv(0.1,chem.cas="34256-82-1",which.quantile=c(0.05,0.5,0.95))

Run the code above in your browser using DataLab