Learn R Programming

httk (version 1.3)

calc_rblood2plasma: Calculate the constant ratio of the blood concentration to the plasma concentration.

Description

This function calculates the constant ratio of the blood concentration to the plasma concentration. It uses the hematocrit and the red blood cell (RBC) parition coefficient as predicted by the Schmitt (2008) method.

Usage

calc_rblood2plasma(chem.cas=NULL, chem.name=NULL, default.to.human=F, species="Human")

Arguments

chem.name
Either the chemical name or the CAS number must be specified.
chem.cas
Either the CAS number or the chemical name must be specified.
default.to.human
Substitutes missing animal values with human values if true.
species
Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or default "Human").

Details

When species is specified as rabbit, dog, or mouse, the function uses the appropriate physiological data(volumes and flows) but substitues human fraction unbound, partition coefficients, and intrinsic hepatic clearance.

References

Schmitt W. "General approach for the calculation of tissue to plasma partition coefficients." Toxicology In Vitro, 22, 457-467 (2008).

Examples

Run this code
calc_rblood2plasma(chem.name="Bisphenol A")
calc_rblood2plasma(chem.name="Bisphenol A",species="Rat")

Run the code above in your browser using DataLab