Learn R Programming

httk (version 2.3.0)

httk-package: tools:::Rd_package_title("httk")

Description

tools:::Rd_package_description("httk")

Arguments

References

PowerPoint Presentation: High-Throughput Toxicokinetics (HTTK) R package

Toxicokinetics at the U.S. Environmental Protection Agency

Breen et al. (2021): High-throughput PBTK models for in vitro to in vivo extrapolation (tools:::Rd_expr_doi("10.1080/17425255.2021.1935867"))

Pearce et al. (2017): httk: R Package for High-Throughput Toxicokinetics (tools:::Rd_expr_doi("10.18637/jss.v079.i04"))

Armitage et al. (2014): Application of mass balance models and the chemical activity concept to facilitate the use of in vitro toxicity data for risk assessment (tools:::Rd_expr_doi("10.1021/es501955g"))

Honda et al. (2019): Using the concordance of in vitro and in vivo data to evaluate extrapolation assumptions (tools:::Rd_expr_doi("10.1371/journal.pone.0217564"))

Kapraun et al. (2022): Evaluation of a rapid, generic human gestational dose model (tools:::Rd_expr_doi("10.1016/j.reprotox.2022.09.004"))

Linakis et al. (2020): Development and evaluation of a high throughput inhalation model for organic chemicals (tools:::Rd_expr_doi("10.1038/s41370-020-0238-y"))

Pearce et al. (2017): Evaluation and calibration of high-throughput predictions of chemical distribution to tissues (tools:::Rd_expr_doi("10.1007/s10928-017-9548-7"))

Ring et al. (2017): Identifying populations sensitive to environmental chemicals by simulating toxicokinetic variability (tools:::Rd_expr_doi("10.1016/j.envint.2017.06.004"))

Sipes et al. (2017): An Intuitive Approach for Predicting Potential Human Health Risk with the Tox21 10k Library (tools:::Rd_expr_doi("10.1021/acs.est.7b00650"))

Wambaugh et al. (2015): Toxicokinetic Triage for Environmental Chemicals (tools:::Rd_expr_doi("10.1093/toxsci/kfv118"))

Wambaugh et al. (2018): Evaluating In Vitro-In Vivo Extrapolation of Toxicokinetics (tools:::Rd_expr_doi("10.1093/toxsci/kfy020"))

Wambaugh et al. (2019): Assessing Toxicokinetic Uncertainty and Variability in Risk Prioritization (tools:::Rd_expr_doi("10.1093/toxsci/kfz205"))

Wetmore et al. (2015): Incorporating High-Throughput Exposure Predictions with Dosimetry-Adjusted In Vitro Bioactivity to Inform Chemical Toxicity Testing (tools:::Rd_expr_doi("10.1093/toxsci/kfv171"))

The U.S. EPA ExpoCast (Exposure Forecasting) Project

See Also

httkpop