Usage
calc_mc_oral_equiv(conc,chem.name=NULL,chem.cas=NULL,which.quantile=0.95,
species="Human",input.units='uM',output.units='mg',
suppress.messages=F,return.samples=F,...)Arguments
conc
Bioactive in vitro concentration in units of uM.
chem.name
Either the chemical name or the CAS number must be specified.
chem.cas
Either the CAS number or the chemical name must be specified.
suppress.messages
Suppress text messages.
input.units
Units of given concentration, default of uM but can also be mg/L.
output.units
Units of dose, default of 'mg' for mg/kg BW/ day or 'mol' for mol/ kg BW/ day.
which.quantile
Which quantile from Monte Carlo simulation is requested. Can be a vector.
species
Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or default "Human").
return.samples
Whether or not to return the vector containing the samples from the simulation instead of the selected quantile.
...
Additional parameters passed to calc_mc_css.